#
# spec file for package nvim-lspconfig
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvim-lspconfig
Version:        2.2.0
Release:        1.1
Summary:        Quickstart configs for Nvim LSP
License:        Apache-2.0
URL:            https://github.com/neovim/nvim-lspconfig
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  neovim >= 0.11
Requires:       neovim >= 0.11
BuildArch:      noarch

%description
default Nvim LSP client configurations for various LSP servers

%package doc
Summary:        Documentation for %{name}

%description doc
%{summary}.

%prep
%autosetup
%fdupes -s doc

%build
nvim -u NONE -i NONE -e --headless -c "helptags doc" -c quit

%install
install -d %{buildroot}%{_datadir}/nvim/runtime/
cp -r lua plugin %{buildroot}%{_datadir}/nvim/runtime/

%files
%license LICENSE.md
%doc CONTRIBUTING.md README.md
%{_datadir}/nvim/runtime/lua/lspconfig
%{_datadir}/nvim/runtime/lua/lspconfig.lua
%{_datadir}/nvim/runtime/plugin/lspconfig.lua

%files doc
%doc doc

%changelog
* Mon May 26 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.2.0:
  * fix(configs): remove sanitize_cmd
  * feat(ts_ls): provide command to run source actions
  * fix: add pylyzer dependency info (erg)
  * feat(docgen.lua): improve vimdoc generator
  * feat(powershell_es): add vim.lsp.config support
  * feat(efm): add vim.lsp.config support
  * fix(powershell_es): typo bundlePath -> bundle_path
  * feat(docgen.lua): convert @brief codeblocks for vimdoc
  * docs: cleanup
  * fix(rust_analyzer): nvim_echo must not be called in a fast event context
  * Support for non-conventional package.json5
  * fix: improve typescript server path search for ts dependents lsp
  * fix(eslint): check nil before on_dir
  * fix(mesonlsp): improved root detection
  * feat: laravel-ls
  * fix(lsp/zk): fix user command options; invalid key description
  * fix(eslint): require workspace instead of checking root dir for nil value
  * Revert "fix(configs): remove sanitize_cmd"
  * fix(texlab): Improve root detection for Latexmk projects
  * fix(configs): execute sanitize_cmd only on windows to speed up WSL
  * feat(ccls): add vim.lsp.config support
  * fix(ast_grep): workspace_required=true
  * fix(doc): Correct lua_ls documentation
  * docs(lua_ls): add field Lua.runtime.path to example config for Nvim Lua
  * feat(oxlint): added oxlint lsp config
  * fix(omnisharp): update executable name
  * fix(taplo): add Taplo configuration files to root markers
  * Feature: migrate builtin commands
  * fix(configs): eliminate some usages of root_pattern
  * feat(vectorcode_server): add vim.lsp.config support
  * feat(jsonnet_ls): jsonnet_ls lsp
  * feat(tailwindcss): Add Tailwind detection for Elixir Phoenix projects
  * refactor: generalize insert_package_json()
  * feat(ty): Add ty lsp config
  * fix(gopls): prioritise go.work over go.mod
  * Rename volar to vue_ls and remove vuels
  * feat: pyrefly
  * docs(eslint): update on_attach example
  * fix(gh_actions_ls): use root_dir and add init_options
  * fix(gopls): schedule vim.notify in on_exit
  * feat(matlab_ls): vim.lsp.config support
  * feat(tailwindcss): map elixir and heex ft to phoenix-heex
  * feat(tailwindcss): Sync tailwind-tools.nvim root detection
  * feat(vespa_ls): Add vespa_ls config
  * feat(golangci_lint_ls): add support for v1
  * fix(nushell): avoid nil root_dir
  * feat: add kotlin_lsp from jetbrains
  * feat: tombi
* Sat Apr 26 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.1.0:
  * Neovim 0.11 migration
  * feat(typos-lsp): support pyproject.toml and Cargo.toml
  * fix(docs): docgen.lua reads from lua/*.lua
  * docs: change contributing.md to new style lsp config
  * feat(gh_actions_ls): add vim.lsp.config support
  * feat(ast_grep): Update filetypes
  * fix(gh_actions_ls): add workspace_required
  * feat(omnisharp): add vim.lsp.config support
  * feat: sqruff
  * feat(biome): vim.lsp.config support, with workspace_required and proper root_dir
  * feat(zls): add vim.lsp.config support
  * fix(rust_analyzer): call on_dir callback when reusing client
  * update vim.lsp.config anchor link href
  * feat(astroJS): add vim.lsp.config support
  * fix(astro): using vim.fs.jointhpath concat path
  * feat(volar): add vim.lsp.config support
  * fix(readme): update vim.lsp.config anchor links
  * feat: emmylua_ls
  * feat: angularls
  * feat(tailwind): add vim.lsp.config support
  * feat: add PL/I support
  * feat(atlas): update doc support for atlas-rule filetype
  * feat(eslint): add vim.lsp.config support
  * ci(lint): enforce "Lsp" command name prefix
  * lint: client:exec_cmd()
  * feat(mdx_analyzer): add vim.lsp.config support
  * fix(sqls): install instructions
  * ci(lint): check @brief docstring placement
  * fix(mdx_analyzer): remove invalid field and update brief
  * fix(docgen.lua): omnisharp "--hostPID" arg always changes
  * ci(lint): deprecate util.path.is_descendant() on Nvim 0.11+
  * fix(tailwindcss): improved root dir detection for tailwind v4
  * fix(unocss): add workspace_required to true
  * rpmspec: Updated cmd and description
  * refactor: deprecate util.path.search_ancestors()
  * refactor: deprecate util.validate_bufnr()
  * feat: Add gnls config
  * feat(roslyn_ls): add initial config as vim.lsp.config
  * fix(roslyn_ls): use absolute paths when open .sln and .csproj files
  * feat(ts_ls): add _typescript.rename handler
* Sun Apr 13 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.0.0:
  * feat: require Nvim 0.10+
  * refactor: deprecate util functions
  * refactor: deprecate util.get_lsp_clients
  * refactor: deprecate add_hook_before/after
  * docs: cleanup
  * refactor: deprecate get_active_client_by_name
  * feat: rpmspec
  * feat(bqls): Add bqls support
  * fix(openedge_ls): Update configuration
  * feat(tinymist): implement simple workspace commands
  * stylelint config update
  * refactor: replace all instances of vim.loop with vim.uv
* Sun Apr  6 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.8.0:
  * fix!: remove lua as root marker
  * fix(rust_analyzer): fix broken rust analyzer link
  * fix(sourcekit): use textDocument/diagnostic over publishDiagnostics
  * refactor(docgen): use vim.text.indent()
  * fix(docgen): root_dir doc shows paths from CI env
  * Update bacon_ls.lua to reflect new configuration
  * chore(bazelrc_lsp): Invoke lsp subcommand explicitly
  * fix(postgresql_lsp): update command to use lsp-proxy argument
  * gleam: fix broken installation description
  * feat: add systemd-language-server
  * fix: rename systemd-language-server to systemd_ls
  * Chore and doc tweaks to QML-related LSPs
  * feat: muon
  * fix(tailwindcss): improved tailwindcss detection
  * fix(ltex_plus): add latex to enabled settings
  * feat: postgrestools
  * fix(biome): improved biomejs detection
  * fix(golangci-lint): fix typo in commang argument
  * feat: alias :LspInfo to :checkhealth vim.lsp
  * feat: vectorcode-server
  * fix(golangci-lint): disable stats in json output
  * fix: ":checkhealth lspconfig" fails on Nvim 0.11
  * fix(postgres_lsp): re-enable single file support
  * Update wgsl-analyzer docs to correct install instructions
  * fix(sourcekit): URL & add dynamic reg. for didChangeWatchedFiles
  * fix(docgen): regenerate configs.txt with correct :help format
  * fix(docgen): :help (vimdoc) format
  * feat(ada_ls): update documentation and support alire.toml files
  * fix(tblgen): find tablegen_compile_commands.yml
  * feat(svelte): command to migrate to svelte 5
  * feat: add just language server configuration
* Mon Feb 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.7.0:
  * docs: fix broken documentation link in rust_analyzer config
  * feat(harper-ls): added new languages and updated links
  * feat: dts-lsp
  * fix(health.lua): increased version check cmd timeout
  * feat: add wasm-language-tools
  * docs: don't skip VIMRUNTIME in lua lsp if ~/.config/nvim/.luarc.json exists
  * docs(atlas): add treesitter instructions
  * feat(oxc_language_server): add OxcFixAll command
  * fix(angularls): trim leading characters from version
  * fix(nushell): root_dir should avoid returning nil
  * docs: heading levels for veridian fixed
  * feat(r_language_server): add quarto filetype
  * fix(lua_ls): return longest root path
  * Add config for turbo-language-server
  * feat: add air lsp
* Mon Feb 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.6.0:
  * revert: "refactor!: make available_servers function private"
  * fix(angularls): set Angular core version for backwards compatibility
  * fix(angularls): handle nil while checking angular core version
- update to 1.5.0:
  * fix(gh_actions_ls): Fix incorrect rootdir resolution
  * fix: remove validation from configs.lua
  * fix(astro,volar): correct 'typescript/lib' path for TypeScript LSP
  * feat: oxc-language-server
- update to 1.4.0:
  * fix(powershell_es): add root pattern
  * fix(clojure_lsp): adds single_file_support for clojure
  * Feat: add lua 3rd party language servers
  * feat: gh-actions-language-server
  * feat(gh_actions_ls): use root_dir to decide whether to attach
  * feat: add typst to the list of languages harper supports
  * feat: Alloy language server
  * Improve alloy_ls docs
  * feat(asm_lsp): add NASM config support and single_file support
  * refactor: comment util.path.is_descendant to prepare deperecation in future
  * refactor!: make available_servers function private
  * docs: Use a maintained fork for kubernetes-json-schema in the example
  * build: add -q flag to luacheck
  * build: remove docgen.sh
  * refactor: silence luals warnings
  * docs: fix typo
  * fix: fix incorrect root finding
* Sun Jan  5 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.3.0:
  * refactor: deprecate util.path.join
  * refactor: deprecate util.path.path_separator
  * refactor: silence luals warnings
  * refactor: deprecate util.path.iterate_parents
  * feat: add server configuration for autohotkey_lsp (init)
  * refactor!: remove public interface of util.path.traverse_parents
  * fix(mdx-analyzer): Duplicate node_modules folder causing errors, and
    filetypes option
  * fix: add build.gradle.kts for java language server
  * feat: cue language server
  * feat(ccls): add CclsSwitchSourceHeader
  * fix(ccls): typo on request method
  * refactor(clangd): imporve switchsourceheader handler
  * fix(clangd): fix switchSourceHeader detection
  * docs(ruby_lsp): Remove instructions for adding ruby-lsp to Gemfile
  * feat: Update Harper's Supported Languages
  * feat: atlas language server
  * fix(msbuild): more root patterns
* Mon Dec 30 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.2.0:
  * refactor: deprecate util.find_package_json_ancestor
  * Fix for vim.fs.find regression not returning parent directory
  * refactor: deprecate util.find_git_ancestor
  * refactor!: remove util.path.escape_wildcards
  * refactor!: remove util.path.is_absolute
  * fix ruff and ruff_lsp returning a function from root pattern
  * feat(msbuild): config instruction for filetypes
  * refactor: fix luals warnings
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- initial packaging
